==> haskell-hls-ormolu-plugin-2.1.0.0-103-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-ormolu-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-ormolu-plugin-2.1.0.0-6GBx2SEsJskJ00DczJZRfq
key:                  hls-ormolu-plugin-2.1.0.0-6GBx2SEsJskJ00DczJZRfq
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cfc46b9c15896a22b797d51093d31df6
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-2.1.0.0-6GBx2SEsJskJ00DczJZRfq
depends:
    base-4.18.2.1 extra-1.7.16-3o8MjPiNQTlLg74BSenHLy
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-th-9.6.6
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1
    ormolu-0.6.0.0-4FP0SmtlYEjKz5nBmJkNQ8 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-ormolu-plugin-2.1.0.0-105-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-ormolu-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-ormolu-plugin-2.1.0.0-HVsgGM6uXvfLGpgoPAnjpB
key:                  hls-ormolu-plugin-2.1.0.0-HVsgGM6uXvfLGpgoPAnjpB
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  94ca4569bf7224922ccb5b43da02353c
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-2.1.0.0-HVsgGM6uXvfLGpgoPAnjpB
depends:
    base-4.18.2.1 extra-1.7.16-IkudFHstV64EKMSGT8IWWb
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-th-9.6.6
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    mtl-2.3.1 ormolu-0.6.0.0-5EXHXBmD8HN9DSAYOg9vhr text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
